@@ -5,7 +5,9 @@ def ends_with_semi_colon(contents: str) -> bool:
     """
     Returns `True` if a given line ends with a semi-colon.
     """
-    return contents.rstrip().endswith(';')
+    # FIXME add "is_statement"
+    contents = contents.strip()
+    return contents.endswith(';') and not contents == '};'
 
 
 def has_balanced_delimiters(contents: str) -> bool:
